@@ -30,7 +30,7 @@ setClass(Class = "MxModel",
 		independent = "logical",
 		options = "list",
 		output = "list",
-		runstate = "list",
+		runstate = "list",  # DEPRECATED
 		.newobjects = "logical",
 		.resetdata = "logical",
 		.wasRun = "logical",
