@@ -52,12 +52,12 @@ public:
 
 	omxLISRELExpectation(omxState *st, int num) : super(st, num), numExoPred(0) {}
 	virtual ~omxLISRELExpectation();
-	virtual void init();
-  virtual void connectToData();
-	virtual void compute(FitContext *fc, const char *what, const char *how);
-	virtual void populateAttr(SEXP expectation);
-	virtual omxMatrix *getComponent(const char*);
-	virtual void getExogenousPredictors(std::vector<int> &out);
+	virtual void init() override;
+  virtual void connectToData() override;
+	virtual void compute(FitContext *fc, const char *what, const char *how) override;
+	virtual void populateAttr(SEXP expectation) override;
+	virtual omxMatrix *getComponent(const char*) override;
+	virtual void getExogenousPredictors(std::vector<int> &out) override;
 
 	void studyExoPred();
 };
