@@ -29,9 +29,9 @@ struct ssMLFitState : omxFitFunction {
 	omxMatrix* otherRowwiseValues;
 
 	virtual ~ssMLFitState();
-	virtual void init();
-	virtual void compute(int ffcompute, FitContext *fc);
-	virtual void populateAttr(SEXP algebra);
+	virtual void init() override;
+	virtual void compute(int ffcompute, FitContext *fc) override;
+	virtual void populateAttr(SEXP algebra) override;
 };
 
 void ssMLFitState::populateAttr(SEXP algebra)
